@@ -520,11 +520,11 @@ class LaunchStackTask(HastexoTask):
             port = 3389
 
         connected = False
-        s = socket.socket()
-        s.settimeout(self.get_sleep_timeout())
+        conn = None
         while not connected:
             try:
-                s.connect((stack_ip, port))
+                conn = socket.create_connection((stack_ip, port),
+                                                self.get_sleep_timeout())
             except SoftTimeLimitExceeded:
                 raise
             except Exception:
@@ -532,7 +532,8 @@ class LaunchStackTask(HastexoTask):
             else:
                 connected = True
             finally:
-                s.close()
+                if conn:
+                    conn.close()
 
     def check_stack(self, stack_outputs, was_resumed, provider):
         """
@@ -852,6 +853,9 @@ class CheckStudentProgressTask(HastexoTask):
         for test in self.tests:
             try:
                 remote_exec(ssh, test, reuse_sftp=sftp)
+            except RemoteExecTimeout as e:
+                logger.warning("Timeout when running test: %s" % e)
+                raise
             except RemoteExecException as e:
                 msg = e.args[0]
                 hint = msg.decode() if isinstance(msg, bytes) else str(msg)
